@@ -144,7 +144,7 @@ def debable(labellings,pivot,subsample_size='none'):
 
 def accuracy(preds,targets,subsample_size='none',precision=4):
     if get_num_labels(preds) == 1:
-        return np.bincounts(targets).max()
+        return np.bincount(targets).max()/np.prod(targets.shape)
     if preds.shape != targets.shape:
         raise TranslationError(f"preds shape: {preds.shape} doesn't equal targets shape: {targets.shape}")
     if len(preds) == 0:
